@@ -6,6 +6,7 @@ from slapp_py.core_classes.discord import Discord
 from slapp_py.core_classes.friend_code import FriendCode
 from slapp_py.core_classes.name import Name
 from slapp_py.core_classes.skill import Skill
+from slapp_py.core_classes.socials.plus_membership import PlusMembership
 from slapp_py.core_classes.socials.sendou import Sendou
 from slapp_py.core_classes.socials.twitch import Twitch
 from slapp_py.core_classes.socials.twitter import Twitter
@@ -31,6 +32,9 @@ class Player:
     names: List[Name]
     """Back-store for the names of this player. The first element is the current name."""
 
+    plus_membership: List[PlusMembership]
+    """Back-store for the PlusMembership Profiles of this player."""
+
     skill: Skill
     """This player's calculated TrueSkill values"""
 
@@ -63,6 +67,7 @@ class Player:
                  discord: Optional[Discord] = None,
                  friend_codes: Optional[List[FriendCode]] = None,
                  skill: Optional[Skill] = None,
+                 plus_membership: Optional[List[PlusMembership]] = None,
                  sendou_profiles: Optional[List[Sendou]] = None,
                  twitch_profiles: Optional[List[Twitch]] = None,
                  twitter_profiles: Optional[List[Twitter]] = None,
@@ -96,6 +101,7 @@ class Player:
         self.discord = discord or Discord()
         self.friend_codes = friend_codes or []
         self.skill = skill or Skill()
+        self.plus_membership = plus_membership or []
         self.sendou_profiles = sendou_profiles or []
         self.twitter_profiles = twitter_profiles or []
         self.twitch_profiles = twitch_profiles or []
@@ -129,6 +135,7 @@ class Player:
                 sorted(
                     set(
                         sum([x.sources for x in self.names]
+                            + [x.sources for x in self.plus_membership]
                             + [x.sources for x in self.sendou_profiles]
                             + [x.sources for x in self.twitch_profiles]
                             + [x.sources for x in self.twitter_profiles]
@@ -150,6 +157,7 @@ class Player:
             discord=Discord.from_dict(obj.get("Discord")) if "Discord" in obj else None,
             friend_codes=from_list(lambda x: FriendCode.from_dict(x), obj.get("FCs")),
             names=from_list(lambda x: Name.from_dict(x), obj.get("N")),
+            plus_membership=from_list(lambda x: PlusMembership.from_dict(x), obj.get("Plus")),
             sendou_profiles=from_list(lambda x: Sendou.from_dict(x), obj.get("Sendou")),
             skill=Skill.from_dict(obj.get("Skill")) if "Skill" in obj else Skill(),
             teams=deserialize_uuids(obj, "Teams"),
@@ -174,6 +182,8 @@ class Player:
         result["Id"] = self.guid.__str__()
         if len(self.names) > 0:
             result["N"] = to_list(lambda x: Name.to_dict(x), self.names)
+        if len(self.plus_membership) > 0:
+            result["Plus"] = to_list(lambda x: PlusMembership.to_dict(x), self.plus_membership)
         if len(self.sendou_profiles) > 0:
             result["Sendou"] = to_list(lambda x: Sendou.to_dict(x), self.sendou_profiles)
         if not self.skill.is_default:
@@ -224,6 +234,9 @@ class Player:
             result.discord.usernames.extend(player.discord.usernames)
             result.discord.usernames = list(set(result.discord.usernames))
 
+            result.plus_membership.extend(player.plus_membership)
+            result.plus_membership = list(set(result.plus_membership))
+
             result.sendou_profiles.extend(player.sendou_profiles)
             result.sendou_profiles = list(set(result.sendou_profiles))
 
