@@ -6,7 +6,8 @@ from os.path import isfile
 import dotenv
 from battlefy_toolkit.resolvers.DiscordIdResolver import DiscordIdResolver
 
-if __name__ == '__main__':
+
+def transform_sendou_file():
     dotenv.load_dotenv()
     resolver = DiscordIdResolver(os.getenv("BOT_TOKEN"))
 
@@ -53,3 +54,7 @@ if __name__ == '__main__':
 
         with open(sendou_path, 'w', encoding='utf-8') as outfile:
             json.dump(players_snapshot, outfile)
+
+
+if __name__ == '__main__':
+    transform_sendou_file()
